@@ -2,11 +2,13 @@
 #' @export
 get_predict.glimML <- function(model,
                                newdata = insight::get_data(model),
+                               vcov = FALSE,
+                               conf_level = 0.95,
                                type = "response",
                                ...) {
 
-    assert_dependency("aod")
-    out <- aod::predict(model, 
+    assert_dependency("aod") # need access to the predict method
+    out <- aod::predict(model,
                         newdata = newdata,
                         type = type,
                         ...)
@@ -25,12 +27,3 @@ set_coef.glimML <- function(model, coefs) {
     model@fixed.param[names(coefs)] <- coefs
     model
 }
-
-
-#' @rdname get_vcov
-#' @export
-get_vcov.glimML <- function(model, ...) {
-    assert_dependency("aod")
-    out <- aod::vcov(model)
-    return(out)
-}
