@@ -5,7 +5,8 @@ sanity_model_specific.brmsfit <- function(model, ...) {
     # terms: brmsfit objects do not have terms immediately available
     te <- tryCatch(attr(stats::terms(stats::formula(model)$formula), "term.labels"), error = function(e) NULL)
     if (any(grepl("^factor\\(", te))) {
-        stop("The `factor()` function cannot be used in the model formula of a `brmsfit` model. Please convert your variable to a factor before fitting the model, or use the `mo()` function to specify monotonic variables (see the `brms` vignette on monotonic variables).")
+        stop("The `factor()` function cannot be used in the model formula of a `brmsfit` model. Please convert your variable to a factor before fitting the model, or use the `mo()` function to specify monotonic variables (see the `brms` vignette on monotonic variables).",
+             call. = FALSE)
     }
 }
 
@@ -24,12 +25,14 @@ get_coef.brmsfit <- function(model, ...) {
 #' @export
 get_predict.brmsfit <- function(model,
                                 newdata = insight::get_data(model),
+                                vcov = FALSE,
+                                conf_level = 0.95,
                                 type = "response",
                                 ...) {
 
     assert_dependency("rstantools")
 
-    checkmate::assert_choice(type, choices = c("response", "link", "prediction"))
+    checkmate::assert_choice(type, choices = c("response", "link", "prediction", "average"))
 
     if (type == "link") {
         draws <- rstantools::posterior_linpred(
@@ -46,6 +49,12 @@ get_predict.brmsfit <- function(model,
             model,
             newdata = newdata,
             ...)
+    } else if (type == "average") {
+        draws <- brms::pp_average(
+            model,
+            newdata = newdata,
+            summary = FALSE,
+            ...)
     }
 
     if ("rowid_internal" %in% colnames(newdata)) {
@@ -72,7 +81,7 @@ get_predict.brmsfit <- function(model,
             group = rep(colnames(out), each = nrow(out)),
             predicted = c(out))
     } else {
-        stop("marginaleffects cannot extract posterior draws from this model. Please report this problem to the Bug tracker with a reporducible example: https://github.com/vincentarelbundock/marginaleffects/issues")
+        stop("marginaleffects cannot extract posterior draws from this model. Please report this problem to the Bug tracker with a reporducible example: https://github.com/vincentarelbundock/marginaleffects/issues", call. = FALSE)
     }
 
     # group for multi-valued outcome
@@ -97,3 +106,17 @@ get_group_names.brmsfit <- function(model, ...) {
     }
     return(out)
 }
+
+
+#' @rdname get_vcov
+#' @export
+get_vcov.brmsfit <- function(model,
+                             vcov = NULL,
+                             ...) {
+    if (!is.null(vcov) && !is.logical(vcov)) {
+        msg <- "The `vcov` argument is not supported for models of this class."
+        warning(msg, call. = FALSE)
+    }
+    return(NULL)
+}
+
