@@ -2,11 +2,11 @@
 #' @export
 get_predict.clm <- function(model,
                             newdata = insight::get_data(model),
+                            vcov = FALSE,
+                            conf_level = 0.95,
                             type = "response",
                             ...) {
 
-    checkmate::assert_choice(type, choices = c("response", "prob"))
-
     if (type == "response") {
         type <- "prob"
     }
@@ -18,23 +18,22 @@ get_predict.clm <- function(model,
     resp <- insight::find_response(model)
     newdata <- newdata[, setdiff(colnames(newdata), resp), drop = FALSE]
 
-    # Corner case: The `predict.clm` method does not make predictions when the
-    # response was transformed to a factor in the formula AND the response is
-    # missing from `newdata`.
-    lhs <- names(attr(stats::terms(model), "dataClasses"))[1]
-    if (isTRUE(grepl("^factor\\(", lhs))) {
-        stop("The response variable should not be transformed to a factor in the formula. Please convert the variable to factor before fitting your model.")
-    }
 
     pred <- stats::predict(model,
                            newdata = newdata,
                            type = type)$fit
 
     out <- data.frame(
-        rowid = rep(1:nrow(pred), times = ncol(pred)),
         group = rep(colnames(pred), each = nrow(pred)),
         predicted = c(pred))
 
+    # often an internal call
+    if ("rowid" %in% colnames(newdata)) {
+        out$rowid <- rep(newdata$rowid, times = ncol(pred))
+    } else {
+        out$rowid <- rep(1:nrow(pred), times = ncol(pred))
+    }
+
     return(out)
 }
 
@@ -42,3 +41,19 @@ get_predict.clm <- function(model,
 #' @rdname get_group_names
 #' @export
 get_group_names.clm <- get_group_names.polr
+
+
+#' @include sanity_model.R
+#' @rdname sanity_model_specific
+#' @keywords internal
+sanity_model_specific.clm <- function(model, ...) {
+
+    # Corner case: The `predict.clm` method does not make predictions when the
+    # response was transformed to a factor in the formula AND the response is
+    # missing from `newdata`.
+    lhs <- names(attr(stats::terms(model), "dataClasses"))[1]
+    if (isTRUE(grepl("^factor\\(", lhs))) {
+        stop("The response variable should not be transformed to a factor in the formula. Please convert the variable to factor before fitting your model.",
+             call. = FALSE)
+    }
+}
