@@ -25,9 +25,10 @@ plot_cme <- function(model,
                      effect,
                      condition,
                      type = "response",
-                     conf.int = TRUE,
-                     conf.level = 0.95,
-                     draw = TRUE) {
+                     vcov = NULL,
+                     conf_level = 0.95,
+                     draw = TRUE,
+                     ...) {
 
     # get data to know over what range of values we should plot
     dat <- insight::get_data(model)
@@ -60,8 +61,8 @@ plot_cme <- function(model,
 
     # condition 1
     if (is.numeric(dat[[condition1]]) && !isTRUE(attr(dat[[condition1]], "factor"))) {
-        at_list[[condition1]] <- seq(min(dat[[condition1]], na.rm = TRUE), 
-                                     max(dat[[condition1]], na.rm = TRUE), 
+        at_list[[condition1]] <- seq(min(dat[[condition1]], na.rm = TRUE),
+                                     max(dat[[condition1]], na.rm = TRUE),
                                      length.out = 25)
     } else {
         at_list[[condition1]] <- unique(dat[[condition1]])
@@ -88,48 +89,59 @@ plot_cme <- function(model,
     # create data
     at_list[["model"]] = model
     nd <- do.call("typical", at_list)
-    datplot <- marginaleffects(model, newdata = nd, variables = effect)
+    datplot <- marginaleffects(
+        model,
+        newdata = nd,
+        type = type,
+        vcov = vcov,
+        conf_level = conf_level,
+        variables = effect,
+        ...)
+    draws <- attr(datplot, "posterior_draws")
     colnames(datplot)[colnames(datplot) == condition1] <- "condition1"
     colnames(datplot)[colnames(datplot) == condition2] <- "condition2"
     colnames(datplot)[colnames(datplot) == condition3] <- "condition3"
-    
+
     # colors and linetypes are categorical attributes
     if ("condition2" %in% colnames(datplot)) datplot$condition2 <- factor(datplot$condition2)
     if ("condition3" %in% colnames(datplot)) datplot$condition3 <- factor(datplot$condition3)
 
-    # CIs are automatically added to predictions but not marginaleffects output
-    if (isTRUE(conf.int) && !"conf.low" %in% colnames(datplot)) {
-        alpha <- 1 - conf.level
+    # CIs are automatically added to predictions but (maybe) not marginaleffects output
+    if (!"conf.low" %in% colnames(datplot)) {
+        alpha <- 1 - conf_level
         datplot$conf.low <- datplot$dydx + stats::qnorm(alpha / 2) * datplot$std.error
         datplot$conf.high <- datplot$dydx - stats::qnorm(alpha / 2) * datplot$std.error
     }
 
     # return immediately if the user doesn't want a plot
     if (isFALSE(draw)) {
+        attr(datplot, "posterior_draws") <- draws
         return(datplot)
     } else {
         assert_dependency("ggplot2")
     }
 
+
     # ggplot2
-    p <- ggplot2::ggplot(datplot, ggplot2::aes(x = condition1, 
-                                               y = dydx, 
-                                               ymin = conf.low, 
+    p <- ggplot2::ggplot(datplot, ggplot2::aes(x = condition1,
+                                               y = dydx,
+                                               ymin = conf.low,
                                                ymax = conf.high))
 
     # continuous x-axis
     if (is.numeric(datplot$condition1)) {
-        if (isTRUE(conf.int) && "conf.low" %in% colnames(datplot)) {
+        if ("conf.low" %in% colnames(datplot)) {
              p <- p + ggplot2::geom_ribbon(ggplot2::aes(fill = condition2), alpha = .1)
         }
         p <- p + ggplot2::geom_line(ggplot2::aes(color = condition2, linetype = condition3))
+
     # categorical x-axis
     } else {
-        if (isTRUE(conf.int) && "conf.low" %in% colnames(datplot)) {
+        if ("conf.low" %in% colnames(datplot)) {
              if (is.null(condition2)) {
                  p <- p + ggplot2::geom_pointrange()
              } else {
-                 p <- p + ggplot2::geom_pointrange(ggplot2::aes(color = condition2), 
+                 p <- p + ggplot2::geom_pointrange(ggplot2::aes(color = condition2),
                                                    position = ggplot2::position_dodge(.15))
              }
         } else {
@@ -137,12 +149,18 @@ plot_cme <- function(model,
         }
     }
 
-    p <- p + ggplot2::labs(x = condition1, 
+    p <- p + ggplot2::labs(x = condition1,
                            y = sprintf("Marginal effect of %s on %s", effect, resp),
                            color = condition2,
                            fill = condition2,
                            linetype = condition3)
 
+    # `effect` is a categorical variable. We plot them in different facets
+    if ("contrast" %in% colnames(datplot) && !all(datplot$contrast == "dY/dX")) {
+        p <- p + ggplot2::facet_wrap(~ contrast)
+    }
+
+
     # set a new theme only if the default is theme_grey. this prevents user's
     # theme_set() from being overwritten
     if (identical(ggplot2::theme_get(), ggplot2::theme_grey())) {
