@@ -7,7 +7,7 @@
 #' @noRd
 sanity_type <- function(model, type, calling_function = NULL) {
 
-    checkmate::assert_character(type, min.len = 1, null.ok = FALSE)
+    checkmate::assert_character(type, len = 1, null.ok = FALSE)
     checkmate::assert_choice(calling_function,
                              choices = c("comparisons", "marginaleffects", "predictions"),
                              null.ok = TRUE)
@@ -27,7 +27,7 @@ sanity_type <- function(model, type, calling_function = NULL) {
         if (!all(type %in% c(valid$base, valid$insight))) {
             msg <- sprintf("The `type` argument for models of class `%s` must be an element of: %s",
                            class(model)[1], paste(sort(valid$base), collapse = ", "))
-            stop(msg)
+            stop(msg, call. = FALSE)
         } else {
             base_from_insight <- valid$base[match(type, valid$insight)]
             base <- ifelse(is.na(base_from_insight), type, base_from_insight)
