@@ -2,4 +2,4 @@ library(testthat)
 library(marginaleffects)
 library(margins)
 
-test_check("marginaleffects")
+# test_check("marginaleffects")
