@@ -14,32 +14,14 @@ test_that("type dictionary does not include duplicates", {
 })
 
 
-test_that("multiple prediction types", {
-    skip_if_not_installed("pscl")
-    requiet("pscl")
-    data("bioChemists", package = "pscl")
-    model <- hurdle(art ~ phd + fem | ment, data = bioChemists, dist = "negbin")
-    mfx <- marginaleffects(model, type = c("response", "zero"))
-    expect_true(all(c("response", "zero") %in% mfx$type))
-})
-
-
-test_that("predicted values are added to the data.frame", {
-    mod <- glm(am ~ mpg * wt, data = mtcars, family = binomial)
-    mfx <- marginaleffects(mod, type = "response")
-    expect_true("response" %in% mfx$type)
-    mfx <- marginaleffects(mod, type = c("response", "link"))
-    expect_true(all(c("response", "link") %in% mfx$type))
-})
-
-
-test_that("multiple prediction types", {
-    skip_if_not_installed("pscl")
-    requiet("pscl")
-    data("bioChemists", package = "pscl")
-    model <- hurdle(art ~ phd + fem | ment, data = bioChemists, dist = "negbin")
-    mfx <- marginaleffects(model, type = c("response", "zero"))
-    expect_true(all(c("response", "zero") %in% mfx$type))
+test_that("sanity gives informative error for all the functions", {
+    dat <- mtcars
+    dat$cyl <- factor(dat$cyl)
+    mod <- lm(mpg ~ hp + cyl, data = dat)
+    expect_error(comparisons(mod, type = "junk"), regexp = "type.*argument")
+    expect_error(predictions(mod, type = "junk"), regexp = "type.*argument")
+    expect_error(marginaleffects(mod, type = "junk"), regexp = "type.*argument")
+    expect_error(marginalmeans(mod, type = "junk"), regexp = "type.*argument")
 })
 
 
